ukmdb_settings package
======================

Submodules
----------

ukmdb_settings.settings module
------------------------------

.. automodule:: ukmdb_settings.settings
    :members:
    :undoc-members:
    :show-inheritance:

ukmdb_settings.settings_wato module
-----------------------------------

.. automodule:: ukmdb_settings.settings_wato
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ukmdb_settings
    :members:
    :undoc-members:
    :show-inheritance:
